package com.ruoyi.hezhi.mapper;

import com.ruoyi.hezhi.domain.TbMemberMajor;
import org.apache.ibatis.annotations.Param;

import java.util.List;
import java.util.Map;

/**
 * 用户题库专业Mapper接口
 *
 * @author ruoyi
 * @date 2024-11-29
 */
public interface TbMemberMajorMapper
{
    /**
     * 查询用户题库专业
     *
     * @param memberMajorId 用户题库专业主键
     * @return 用户题库专业
     */
    public TbMemberMajor selectTbMemberMajorByMemberMajorId(Long memberMajorId);

    /**
     * 查询用户题库专业列表
     *
     * @param tbMemberMajor 用户题库专业
     * @return 用户题库专业集合
     */
    public List<TbMemberMajor> selectTbMemberMajorList(TbMemberMajor tbMemberMajor);

    /**
     * 新增用户题库专业
     *
     * @param tbMemberMajor 用户题库专业
     * @return 结果
     */
    public int insertTbMemberMajor(TbMemberMajor tbMemberMajor);

    /**
     * 修改用户题库专业
     *
     * @param tbMemberMajor 用户题库专业
     * @return 结果
     */
    public int updateTbMemberMajor(TbMemberMajor tbMemberMajor);

    /**
     * 删除用户题库专业
     *
     * @param memberMajorId 用户题库专业主键
     * @return 结果
     */
    public int deleteTbMemberMajorByMemberMajorId(Long memberMajorId);

    /**
     * 批量删除用户题库专业
     *
     * @param memberMajorIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTbMemberMajorByMemberMajorIds(Long[] memberMajorIds);

    /**
     * 查询用户题库专业
     *
     * @param memberUserId 用户ID
     * @param majorId 专业ID
     * @param resId 资源ID
     * @return 用户题库专业
     */
    public TbMemberMajor selectTbMemberMajorByMemberAndMajorId(@Param("memberUserId") Long memberUserId,
                                                               @Param("majorId")Long majorId,
                                                               @Param("resId")Long resId);

    /**
     * 用户题库专业列表
     *
     * @param params 参数
     * @return 用户题库专业列表
     */
    public List<Map<String, Object>> getMemberMajorList(Map<String, Object> params);

    /**
     * 用户题库专业列表
     *
     * @param params 参数
     * @return 用户题库专业列表
     */
    public List<Map<String, Object>> getMemberMajorByCourseId(Map<String, Object> params);

    /**
     * 用户题库推荐专业列表
     *
     * @return 用户题库推荐专业列表
     */
    public List<Map<String, Object>> getMemberMajorRecommendClassList();
}
